pub fn parse_trainpath_csv(path: &str) -> Result<TrainPath, ProjectionError>Expand description
Parse TrainPath from CSV
Reads a CSV file in the format produced by write_trainpath_csv. Expects columns: netelement_id, probability, start_intrinsic, end_intrinsic, gnss_start_index, gnss_end_index
The overall_probability can be specified in a comment line starting with
# overall_probability: or will default to the average of segment probabilities.
Arguments
path- Path to CSV file
Returns
A TrainPath struct reconstructed from the CSV data